@@ -50,8 +50,12 @@ database Hash-table.'''
                 try:
                     return self._meta.related[name]
                 except KeyError:
-                    raise AttributeError("object '%s' has not attribute %s" % (self,name))
-            
+                    return self.customAttribute(name)
+        
+    def customAttribute(self, name):
+        '''Override this function to provide custom attributes'''
+        raise AttributeError("object '%s' has not attribute %s" % (self,name))
+    
     def __set_field(self, name, field, value):
         if field:
             field.set_value(name,self,value)
@@ -67,7 +71,7 @@ database Hash-table.'''
         if meta.isvalid():
             meta.cursor.add_object(self, commit = commit)
         else:
-            raise ObjectNotValidated('Object %s is not validated')
+            raise ObjectNotValidated('Object %s did not validate. Cannot save to database.' % self)
         return self
     
     def isvalid(self):
@@ -88,7 +92,7 @@ database Hash-table.'''
     def delete(self):
         '''Delete an instance from database. If the instance is not available (it does not have an id) and
 ``StdNetException`` exception will raise.'''
-        meta = self.meta
+        meta = self._meta
         if not meta.has_pk():
             raise StdNetException('Cannot delete object. It was never saved.')
         # Gather related objects to delete
@@ -111,12 +115,7 @@ database Hash-table.'''
                 else:
                     odict.pop(name,None)
         return odict
-    
-    @property
-    def meta(self):
-        '''Return an instance of :ref:`Database Metaclass <database-metaclass>`'''
-        return self._meta
-    
+        
     @classmethod
     def commit(cls):
         return cls._meta.cursor.commit()
