@@ -2,51 +2,26 @@ import datetime
 import unittest
 import logging
 from itertools import izip
+from random import randint
 
 from stdnet.stdtest import TestBase
 from stdnet import orm
 from stdnet.utils import populate
+from stdnet.exceptions import QuerySetError
 
-# Create some models for testing
-
-class Base(orm.StdModel):
-    name = orm.AtomField(unique = True)
-    ccy  = orm.AtomField()
-    
-    def __str__(self):
-        return str(self.name)
-    
-    class Meta:
-        abstract = True
-
-class Instrument(Base):
-    type = orm.AtomField()
-    
-class Fund(Base):
-    pass
-
-class Position(orm.StdModel):
-    instrument = orm.ForeignKey(Instrument, related_name = 'positions')
-    fund       = orm.ForeignKey(Fund)
-    dt         = orm.DateField()
-    
-    def __str__(self):
-        return '%s: %s @ %s' % (self.fund,self.instrument,self.dt)
-    
-    def __init__(self, size = 1, price = 1, **kwargs):
-        self.size  = size
-        self.price = price
-        super(Position,self).__init__(**kwargs)
-    
+from examples.portfolio import Instrument, Fund, Position, PortfolioView, UserDefaultView
 
 orm.register(Instrument)
 orm.register(Fund)
 orm.register(Position)
+orm.register(PortfolioView)
+orm.register(UserDefaultView)
 
 INST_LEN    = 100
-FUND_LEN    = 20
+FUND_LEN    = 10
 POS_LEN     = 30
-NUM_DATES   = 3
+NUM_USERS   = 10
+NUM_DATES   = 2
 
 ccys_types  = ['EUR','GBP','AUD','USD','CHF','JPY']
 insts_types = ['equity','bond','future','cash','option']
@@ -58,6 +33,9 @@ inst_ccys  = populate('choice',INST_LEN, choice_from = ccys_types)
 fund_names = populate('string',FUND_LEN, min_len = 5, max_len = 20)
 fund_ccys  = populate('choice',FUND_LEN, choice_from = ccys_types)
 
+users      = populate('string', NUM_USERS, min_len = 8, max_len = 14)
+view_names = populate('string', 4*FUND_LEN, min_len = 10, max_len = 20)
+
 dates = populate('date',NUM_DATES,start=datetime.date(2009,6,1),end=datetime.date(2010,6,6))
 
 
@@ -65,10 +43,13 @@ dates = populate('date',NUM_DATES,start=datetime.date(2009,6,1),end=datetime.dat
 class TestORM(TestBase):
     
     def setUp(self):
+        '''Create Instruments and Funds commiting at the end for speed'''
         for name,typ,ccy in izip(inst_names,inst_types,inst_ccys):
-            Instrument(name = name, type = typ, ccy = ccy).save()
+            Instrument(name = name, type = typ, ccy = ccy).save(False)
+        Instrument.commit()
         for name,ccy in izip(fund_names,fund_ccys):
-            Fund(name = name, ccy = ccy).save()
+            Fund(name = name, ccy = ccy).save(False)
+        Fund.commit()
     
     def makePositions(self):
         '''Create Positions objects which hold foreign key to instruments and funds'''
@@ -79,26 +60,35 @@ class TestORM(TestBase):
             for dt in dates:
                 for inst in insts:
                     n += 1
-                    Position(instrument = inst, dt = dt, fund = f).save()
+                    Position(instrument = inst, dt = dt, fund = f).save(False)
+        Position.commit()
         return n
         
-    def testLen(self):
-        '''Simply test len of objects greater than zero'''
-        objs = Instrument.objects.all()
-        self.assertTrue(len(objs)>0)
-        
-    def testObject(self):
+    def testGetObject(self):
+        '''Test get method for id and unique field'''
         obj = Instrument.objects.get(id = 1)
         self.assertEqual(obj.id,1)
         self.assertTrue(obj.name)
         obj2 = Instrument.objects.get(name = obj.name)
         self.assertEqual(obj,obj2)
+        
+    def testLen(self):
+        '''Simply test len of objects greater than zero'''
+        objs = Instrument.objects.all()
+        self.assertTrue(len(objs)>0)
     
     def testFilter(self):
-        '''Test filtering'''
+        '''Test filtering on a model without foreignkeys'''
+        try:
+            result = Instrument.objects.get(type = 'equity')
+        except QuerySetError:
+            pass
+        else:
+            self.fail('get query on non-unique field should have failed')
         tot = 0
         for t in insts_types:
             fs = Instrument.objects.filter(type = t)
+            N  = fs.count()
             count = {}
             for f in fs:
                 count[f.ccy] = count.get(f.ccy,0) + 1
@@ -162,7 +152,7 @@ class TestORM(TestBase):
             
         
     def testDeleteSimple(self):
-        '''Test delete on models without without related models'''
+        '''Test delete on models without related models'''
         instruments = Instrument.objects.all()
         funds = Fund.objects.all()
         Ni = len(instruments)
@@ -179,5 +169,28 @@ class TestORM(TestBase):
         T = instruments.delete()
         self.assertEqual(T,Np+Ni)
         
+    def __testNestedLookUp(self):
+        # Create Portfolio views
+        funds = Fund.objects.all()
+        N     = funds.count()
+        for name in view_names:
+            fund = funds[randint(0,N-1)] 
+            PortfolioView(name = name, portfolio = fund).save(False)
+        PortfolioView.commit()
+        views = PortfolioView.objects.all()
+        N = views.count()
+        for user in users:
+            for i in range(0,FUND_LEN): 
+                view = views[randint(0,N-1)]
+                user = UserDefaultView(user = user, view = view).save()
+        UserDefaultView.commit()
+        #
+        #Finally do the filtering
+        N = 0
+        for fund in funds:
+            res = UserDefaultView.objects.filter(view__portfolio = fund)
+            N += res.count()
+            
         
+         
 
